Page 77 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 77

Home

    to 1798.

    inventor of the telegraph. Besides many other voices that
    raised a cry of alarm, George Washington spoke out
    publicly against their efforts to foment revolution.

    in

    1794,

    serious

    western

    insurrection was promoted by a group established by
    Edmond Charles Genet, an [lluminist, and the French

    envoy to the United States. This group, known as the
    Mino Creek Democratic Society, tried to bring about

    secession and set up a separate country in that region.
    This event is referred to by historians as the Whiskey

    At a cost of a million dollars, President Washington
    put down the rebellion and publicly denounced the
    influence of French Illuminists behind it. William P. Hoar

    President Washington believed the revolutionary
    Democratic Clubs were responsible for the so-called
    Whiskey Rebellion. Whatever the case, it was certainly
    the spirit of the French Revolution that sustained it.
    Albert Beveridge comments that "when the troops sent
    out to put down insurrection reached Harrisburg, they
    found the French flag flying over the courthouse."
    President Washington said: "I consider this insurrection
    as the first formidable fruit of the Democratic Societies

    72

    The Secret Side of History

    John Robison's book Proofs of a Conspiracy from 1797

    Another influential writer who did much to expose the

    activities of the Illuminati in the United States was

    Jedediah Morse, the father of Samuel Morse, the famous

    Pennsylvania

    Rebellion.

    said this about the event: